// restore.e
//
// Fri, 06/12/1992 15:07:19
//
// Purpose:
//
//		This extension is in the class of tidbits.  It modifies
//		Epsilon standard behavior in a transparent manner.  Epsilon
//		has the annoying habit of always throwing away all state
//		information from the current session file if you have the
//		gall to specify a file from the command line (rather than
//		just starting and using dired or C-X C-F.  This routine
//		modifies this behavior so that file state information is
//		restored correctly.
//
// Usage:
//
//		Add restore.doc to edoc, compile and load this file and save
//		the state.  Done.
//
//		The new user variable session_always_restore controls file
//		restoration.  If set to TRUE (1), the behavior will be to
//		read in the session file, then load in all of the specified
//		files on the command line.  The explicitly loaded buffers are
//		presented to the user in the same way as epsilon default.
//		Set to FALSE the variable causes Epsilon to behave as before.
//
//
// Details:
//
//
// Some future directions:
//
//
// The modifications to this code are dedicated to the public domain
// with the caveat that Lugaru is welcome to use this within their
// distribution source code which is supplied with Epsilon.  Use it
// any way you want for whatever purposes.
//
//
//	John Kercheval
//	15563 10th Ave NE
//	Seattle, WA 98155-6209
//	INTERNET: johnk@wrq.com
//	Compu$erve: 72450,3702
//
//
// Modification History:
//
// J. Kercheval Mon, 09/19/1994 22:14:34 Creation
//

#include <eel.h>

#ifndef BOOL
#define BOOL int
#define TRUE 1
#define FALSE 0
#endif

#define MAX_BUF		256

//
// This variable is TRUE (1) if the system should always restore
// files and variables found in the session file even if the command
// line contains some specific file names on it.  Note that if the
// command line does specify files then the window configuration is
// not preserved, just the files and associated variables, marks,
// bookmarks, etc.  If no files are specified on the command line or
// if this variable is FALSE (0) then session restore works as
// the default.
//
user BOOL session_always_restore = TRUE;


////////////////////////////////////////////////////////////////////////////
//
// load_cmd_line_files will restore the epsilon session before
// reading in the command line files and assigning them to windows.
// This subroutine will open all files in the matching the command
// line patterns.
//

load_cmd_line_files(i)
{								/* start at argv[i] */
	int wins = 0,
	    tot_size = window_height,
	    line;
	char fname[FNAMELEN],
	    abs[FNAMELEN],
		*s;

	//
	// restore session if wanted but remove window configuration set
	// as a result
	//
	if (session_always_restore)
		load_session();

	iter = 0;
	one_window();

	//
	// read in the file from the project specification.
	//
	line = -1;
	for (; i < argc; i++) {
		if (argv[i][0] == '+')
			line = strtoi(argv[i] + 1, 10);
		else {
			strcpy(fname, argv[i]);
			s = expand_wildcards ? do_file_match(fname, FM_EXACT)
				: fname;
			if (!s)				/* new file */
				s = fname;
			do {
				strcpy(abs, s);
				if (*abs)
					absolute(abs);
				if (wins < 3 && wins++ > 0) {
					split_window();
					window_height = 1000;
				}
				do_find(abs, strip_returns.default);
				if (line > 0)
					go_line(line);
			} while (expand_wildcards
					 && (s = do_file_match(fname, 0)));
			line = -1;
		}
	}
	for (; window_number > 0; window_number--)
		window_height = tot_size / number_of_windows();
}
